/*
   udm-test.c: an example program about usage of libfreeipmi.
   Copyright (C) 2005 FreeIPMI Core Team

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#if HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#if STDC_HEADERS
#include <string.h>
#endif /* STDC_HEADERS */

#include <freeipmi/freeipmi.h>
#include <freeipmi/udm/udm.h>

int 
main (int argc, char **argv)
{
  char *hostname = NULL; /* ipmi hostname for out-of-band */
  int authentication_type = IPMI_AUTHENTICATION_TYPE_NONE; 
  /* for out-of-band, it can also be IPMI_AUTHENTICATION_TYPE_MD2, 
     IPMI_AUTHENTICATION_TYPE_MD5, IPMI_AUTHENTICATION_TYPE_STRAIGHT_PASSWORD_KEY, 
     IPMI_AUTHENTICATION_TYPE_OEM_PROP */
  char username[] = ""; /* ipmi username for out-of-band */
  char password[] = ""; /* ipmi user's password for out-of-band */
  int priv_level = IPMI_PRIVILEGE_LEVEL_USER; 
  /* for out-of-band, can also be IPMI_PRIVILEGE_LEVEL_CALLBACK, 
     IPMI_PRIVILEGE_LEVEL_OPERATOR, IPMI_PRIVILEGE_LEVEL_ADMIN, IPMI_PRIVILEGE_LEVEL_OEM */
  
  int disable_auto_probe = 0; /* to disable automatic probing, set non-zero here */
  int driver_address = 0; /* driver address, if needed */
  char *driver_device = NULL; /* driver device, if needed */
  
  ipmi_device_t dev;
  fiid_obj_t obj_cmd_rs;
  
  if (hostname != NULL)
    {
      if (!(dev = ipmi_open_outofband (IPMI_DEVICE_LAN, 
				       hostname,
                                       username, 
                                       password, 
                                       authentication_type, 
                                       priv_level,
                                       0, 
                                       0, 
                                       IPMI_FLAGS_DEFAULT)))
	{
	  perror ("ipmi_open_outofband()");
	  exit (EXIT_FAILURE);
	}
    }
  else 
    {
      if (!(dev = ipmi_open_inband (IPMI_DEVICE_KCS, /* can also be any inband device */
				    disable_auto_probe, 
				    driver_address, 
                                    0, /* register spacing */
                                    driver_device, 
                                    IPMI_FLAGS_DEFAULT)))
	{
	  perror ("ipmi_open_inband()");
	  exit (EXIT_FAILURE);
	}
    }
  
  if (!(obj_cmd_rs = fiid_obj_create(tmpl_cmd_get_device_id_rs)))
    {
      perror("fiid_obj_create");
      exit (EXIT_FAILURE);
    }
  if (ipmi_cmd_get_device_id (dev, obj_cmd_rs) != 0)
    {
      perror ("ipmi_cmd()");
      exit (EXIT_FAILURE);
    }
  ipmi_obj_dump (fileno (stdout), obj_cmd_rs);
  
  ipmi_close_device (dev);
  return (0);
}
